octave-maintainers
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Re: 3.2.3 RC2


From: Tatsuro MATSUOKA
Subject: Re: 3.2.3 RC2
Date: Fri, 4 Sep 2009 19:15:59 +0900 (JST)

Hello Ben Abbott and Benjamin Lindner

--- Benjamin Lindner  wrote:

> 
> > 
> > changeset:   9395:54a3fa5d4376
> > user:        Ben Abbott <address@hidden>
> > date:        Thu Aug 06 07:30:34 2009 +0200
> > summary:     Avoid the flickering x11 window seen with rapid gnuplot
> > updates.
> > http://hg.tw-math.de/release-3-2-x/rev/54a3fa5d4376
> > 
> > 
> > The above changeset seems to be the origin by which mouse  zooming in 2D 
> > cannot be used.
> > 
> > I have tested binaries built  by MinGW-4.4.0 (Official Version) and the
> > gnuplot 4.3 cvs for windows
> > (the recent source) is used. The terminal is windows terminal.
> > 
> 
> I can confirm that this changeset breaks interactive usability.
> 
> > Anyway the chanageset should be re-modified to enable us to use mouse
> > zooming in windows terminal on
> > gnuplot backend.
> 
> I agree, this should be fixed, otherwise the gnuplot backend is pretty much 
> useless on windows.

The changeset by Ben should be applied to also to "windows terminal".

The below patch solves the mouse zoom problem for windows term and problem that 
I have asked before

"How can I get successive plot on octave 3.2 as was obtained in octave 3.0.x"

http://www.nabble.com/How-can-I-get-successive-plot-on-octave-3.2-as-was-obtained-in-octave-3.0.x-tc24804743.html#a24839441

********************
--- gnuplot_drawnow.m.org       2009-08-26 15:17:08 +0900
+++ gnuplot_drawnow.m   2009-09-04 18:56:18 +0900
@@ -286,10 +286,10 @@
       ## the canvas size for terminals cdr/corel.
       term_str = sprintf ("%s %s", term_str, size_str);
     endif
     ## Work around the gnuplot feature of growing the x11 window when
when
     ## the mouse and multiplot are set.
     fputs (plot_stream, "unset multiplot;\n");
-    if (! strcmp (term, "x11")
+    if (! ( strcmp (term, "x11") || strcmp (term, "windows") )
         || numel (findall (h, "type", "axes")) > 1
         || numel (findall (h, "type", "image")) > 0)
       fprintf (plot_stream, "%s\n", term_str);
@@ -299,7 +299,7 @@
         endif
       endif
       fputs (plot_stream, "set multiplot;\n");
-    elseif (strcmp (term, "x11"))
+    elseif (strcmp (term, "x11") || strcmp (term, "windows"))
       fprintf (plot_stream, "%s\n", term_str);
       if (nargin == 5)
         if (! isempty (file))
***************************************
 
I do not know whether Ben's patch should be also applied to 'aqua', 'wxt' or 
'qt' term.

Regards

Tatsuto 


--------------------------------------
@@ -286,10 +286,10 @@
       term_str = sprintf ("%s %s", term_str, size_str);
     endif
-    ## Work around the gnuplot feature of growing the x11 window when
+    ## Work around the gnuplot feature of growing the x11 and windows window 
when
     ## the mouse and multiplot are set.
Thanks 10 years!  Yahoo! Shopping and Yahoo! Auctions
http://pr.mail.yahoo.co.jp/ec10years/


reply via email to

[Prev in Thread] Current Thread [Next in Thread]